===============================
networking-vsphere
===============================

A set of Neutron drivers and agents to manage vSphere clusters.

* Free software: Apache license
* Source: http://git.openstack.org/cgit/stackforge/networking-vsphere

Features
--------

* TODO
